# CertSigningReqReissueStatus

Information about a request to reissue a certificate. The request may not immediately build a certificate, but if it does, it will be returned in the new_certificate propery. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**new_certificate** | [**X509Certificate**](X509Certificate.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


